@@ -1,14 +1,15 @@
-'''greedy rule list (based on [this implementation](https://medium.com/@penggongting/implementing-decision-tree-from-scratch-in-python-c732e7c69aea)).
+'''greedy rule list
 Uses CART to learn a list (only a single path), rather than a decision tree.
 '''
 
 import math
-from copy import deepcopy
-
 import numpy as np
+from copy import deepcopy
 from sklearn.base import BaseEstimator
+
 from imodels.rule_list.rule_list import RuleList
 
+
 class GreedyRuleListClassifier(BaseEstimator, RuleList):
     def __init__(self, max_depth=5, class_weight=None, criterion='gini'):
         self.depth = 0
@@ -80,7 +81,7 @@ class GreedyRuleListClassifier(BaseEstimator, RuleList):
                 'col': self.feature_names[col],
                 'index_col': col,
                 'cutoff': cutoff,
-                'val': np.mean(y), # values before splitting
+                'val': np.mean(y),  # values before splitting
                 'flip': flip,
                 'val_right': np.mean(y_right),
                 'num_pts': y.size,
