@@ -7,18 +7,6 @@ from sklearn.utils.validation import check_array, check_is_fitted
 
 class RuleSet:
 
-    @staticmethod
-    def _enum_features(X, feature_names: List[str]) -> Tuple[List[str], Dict[str, str]]:
-        enum_feature_names = [f'feature_{i}' for i in range(X.shape[1])]
-        if feature_names is None:
-            feature_names = enum_feature_names
-        else:
-            feature_clean_fn = lambda f: f.replace(' ', '_').replace('/', '_').replace('<', '_under_')
-            feature_names = list(map(feature_clean_fn, feature_names))
-        feature_dict = {k: v for k, v in zip(enum_feature_names, feature_names)}
-
-        return feature_names, feature_dict
-
     def _get_tree_ensemble(self):
         pass
 
